==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_tab.js <==
/*
._onactive(bool)
*/
_me = obj_tab.prototype;
function obj_tab(){};

_me.__constructor = function(){

	this._isActive = false;
	this._isDisabled = false;
	this._wasActivated = false;
	
	var me = this;

	this.__drawTpl = null;
	this.__drawObj = null;
	this.__drawData = null;

	this.__eLink = mkElement('a',{'href':''});
	this.__eLink.onclick = this.__eLink.onfocus = function(){ me._active(); }

	this.__eLi = mkElement('li');
	this.__eLi.appendChild(this.__eLink);
	
	var elm = this._parent._getAnchor('links');
		elm.appendChild(this.__eLi);
		elm = null;

	/* activate 1st instance in tabs objekt */
	var first = 1;
	for (var i in this._parent){
		if (i.indexOf('_')==0 || this._parent[i]._name == this._name) continue;
		first = 0;
		break;
	}
	if (first) this._active();

	// clear memory
	this._add_destructor('__destruct');
};

/**
 * @Brief: set TITLE for tab
 **/
_me._value = function(v){
	this.__eLink.innerHTML = getLang(v);
};

_me._disabled = function(b){
	if (b == this._isDisabled) return;
	if (b){
		addcss(this.__eLi,'disabled');
		addcss(this._main,'obj_tabdisabled');
	}
	else{
		removecss(this.__eLi,'disabled');
		removecss(this._main,'obj_tabdisabled');
	}
	this._isDisabled = b;
};

/**
 * @Brief: Public function
 **/
_me._active = function(draw){
	if (this._isActive || this._isDisabled) return;

	draw = draw || false;
	this._isActive = true;
	this._wasActivated = true;

	// add <draw>
	if (this.__drawTpl){
		if (count(this.__drawTpl[2]) <= 0 && count(this.__drawData) > 0)
			this.__drawTpl[2] = this.__drawData;
		this._draw(this.__drawTpl[0],this.__drawTpl[1],this.__drawTpl[2]);
		draw = true;
		this.__drawTpl = null;
	}
	// add <obj>
	if (this.__drawObj){
		this.__addObjects(this.__drawObj,null,this.__drawData);
		draw = true;
		this.__drawObj = null;
	}

	// deactivate previous tab
	if (this._parent.__value) this._parent[this._parent.__value].__deactive();
	this._parent.__value = this._name;

	// activate this tab
	this._main.style.display = 'block';
	addcss(this.__eLi,'active');
	
	if (this._onactive) this._onactive(draw);
	this.__exeEvent('onactive',null,{"draw":draw,"owner":this});
};

/**
 * @Brief: Private function to deactivating tab
 * @Date : 3.5.2006 18:55:40
 **/
_me.__deactive = function(){
	if (this._isActive == false) return;

	this._main.style.display = 'none';
	removecss(this.__eLi,'active');

	this._isActive = false;
};

_me.__destruct = function(){
	if (this.__eLink) this.__eLink.parentNode.removeChild(this.__eLink);
	if (this.__eLi) this.__eLi.parentNode.removeChild(this.__eLi);
	
	this.__eLi = null;
	this.__eLink = null;
	this.__eMain = null;
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_tab.js <==
/*
._onactive(bool)
*/
_me = obj_tab.prototype;
function obj_tab(){};

_me.__constructor = function(){

	this._isActive = false;
	this._isDisabled = false;
	this._wasActivated = false;
	
	var me = this;

	this.__drawTpl = null;
	this.__drawObj = null;
	this.__drawData = null;

	this.__eLink = mkElement('a',{'href':''});
	this.__eLink.onclick = this.__eLink.onfocus = function(){ me._active(); }

	this.__eLi = mkElement('li');
	this.__eLi.appendChild(this.__eLink);
	
	var elm = this._parent._getAnchor('links');
		elm.appendChild(this.__eLi);
		elm = null;

	/* activate 1st instance in tabs objekt */
	var first = 1;
	for (var i in this._parent){
		if (i.indexOf('_')==0 || this._parent[i]._name == this._name) continue;
		first = 0;
		break;
	}
	if (first) this._active();

	// clear memory
	this._add_destructor('__destruct');
};

/**
 * @Brief: set TITLE for tab
 **/
_me._value = function(v){
	this.__eLink.innerHTML = getLang(v);
};

_me._disabled = function(b){
	if (b == this._isDisabled) return;
	if (b){
		addcss(this.__eLi,'disabled');
		addcss(this._main,'obj_tabdisabled');
	}
	else{
		removecss(this.__eLi,'disabled');
		removecss(this._main,'obj_tabdisabled');
	}
	this._isDisabled = b;
};

/**
 * @Brief: Public function
 **/
_me._active = function(draw){
	if (this._isActive || this._isDisabled) return;

	draw = draw || false;
	this._isActive = true;
	this._wasActivated = true;

	// add <draw>
	if (this.__drawTpl){
		if (count(this.__drawTpl[2]) <= 0 && count(this.__drawData) > 0)
			this.__drawTpl[2] = this.__drawData;
		this._draw(this.__drawTpl[0],this.__drawTpl[1],this.__drawTpl[2]);
		draw = true;
		this.__drawTpl = null;
	}
	// add <obj>
	if (this.__drawObj){
		this.__addObjects(this.__drawObj,null,this.__drawData);
		draw = true;
		this.__drawObj = null;
	}

	// deactivate previous tab
	if (this._parent.__value) this._parent[this._parent.__value].__deactive();
	this._parent.__value = this._name;

	addcss(this._main,'obj_tab_active');
	addcss(this.__eLi,'active');
	
	if (this._onactive) this._onactive(draw);
	this.__exeEvent('onactive',null,{"draw":draw,"owner":this});
};

/**
 * @Brief: Private function to deactivating tab
 * @Date : 3.5.2006 18:55:40
 **/
_me.__deactive = function(){
	if (this._isActive == false) return;

    removecss(this._main,'obj_tab_active');

	//this._main.style.display = 'none';
	removecss(this.__eLi,'active');

	this._isActive = false;
};

_me.__destruct = function(){
	if (this.__eLink) this.__eLink.parentNode.removeChild(this.__eLink);
	if (this.__eLi) this.__eLi.parentNode.removeChild(this.__eLi);
	
	this.__eLi = null;
	this.__eLink = null;
	this.__eMain = null;
};
